@@ -4,6 +4,5 @@ load_dotenv()
 
 from . import config
 from .client import Abraia, APIError
-from .multiple import Multiple
 
-__all__ = ['config', 'Abraia', 'APIError', 'Multiple']
+__all__ = ['config', 'Abraia', 'APIError']
