@@ -2,7 +2,7 @@ import cv2
 
 
 class Video:
-    def __init__(self, src, output=None):
+    def __init__(self, src=0, output=None):
         self.out = None
         self.quit = False
         self.win_name = ''
@@ -11,7 +11,6 @@ class Video:
         self.width = int(self.cap.get(cv2.CAP_PROP_FRAME_WIDTH))
         self.height = int(self.cap.get(cv2.CAP_PROP_FRAME_HEIGHT))
         self.frame_rate = self.fps
-        print(self.width, self.height, self.fps)
         if output:
             fourcc = cv2.VideoWriter_fourcc(*'mp4v')
             self.out = cv2.VideoWriter(output, fourcc, self.fps, (self.width, self.height))
@@ -37,5 +36,6 @@ class Video:
             self.win_name = 'Video'
             cv2.namedWindow(self.win_name, cv2.WINDOW_GUI_NORMAL)
         cv2.imshow(self.win_name, cv2.cvtColor(frame, cv2.COLOR_RGB2BGR))
-        if (cv2.waitKey(int(self.fps)) & 0xFF == ord('q')) or cv2.getWindowProperty(self.win_name, cv2.WND_PROP_VISIBLE) < 1:
+        ch = 0xFF & cv2.waitKey(int(self.fps))
+        if (ch == 27 or ch == ord('q')) or cv2.getWindowProperty(self.win_name, cv2.WND_PROP_VISIBLE) < 1:
             self.quit = True
